
## CATO-CLI - mutation.accountManagement.removeAccount:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.accountManagement.removeAccount) for documentation on this operation.

### Usage for mutation.accountManagement.removeAccount:

`catocli mutation accountManagement removeAccount -h`

`catocli mutation accountManagement removeAccount <json>`

`catocli mutation accountManagement removeAccount "$(cat < mutation.accountManagement.removeAccount.json)"`

#### Operation Arguments for mutation.accountManagement.removeAccount ####

`accountId` [ID] - (required) N/A    
